# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: steammessages_friendmessages.proto
# plugin: python-betterproto

from dataclasses import dataclass
from typing import List

import betterproto


@dataclass
class CFriendMessages_GetRecentMessages_Request(betterproto.Message):
    steamid1: float = betterproto.fixed64_field(1)
    steamid2: float = betterproto.fixed64_field(2)
    count: int = betterproto.uint32_field(3)
    most_recent_conversation: bool = betterproto.bool_field(4)
    rtime32_start_time: float = betterproto.fixed32_field(5)
    bbcode_format: bool = betterproto.bool_field(6)
    start_ordinal: int = betterproto.uint32_field(7)
    time_last: int = betterproto.uint32_field(8)
    ordinal_last: int = betterproto.uint32_field(9)


@dataclass
class CFriendMessages_GetRecentMessages_Response(betterproto.Message):
    messages: List["CFriendMessages_GetRecentMessages_ResponseFriendMessage"] = betterproto.message_field(1)
    more_available: bool = betterproto.bool_field(4)


@dataclass
class CFriendMessages_GetRecentMessages_ResponseFriendMessage(betterproto.Message):
    accountid: int = betterproto.uint32_field(1)
    timestamp: int = betterproto.uint32_field(2)
    message: str = betterproto.string_field(3)
    ordinal: int = betterproto.uint32_field(4)


@dataclass
class CFriendsMessages_GetActiveMessageSessions_Request(betterproto.Message):
    last_message_since: int = betterproto.uint32_field(1)
    only_sessions_with_messages: bool = betterproto.bool_field(2)


@dataclass
class CFriendsMessages_GetActiveMessageSessions_Response(betterproto.Message):
    message_sessions: List[
        "CFriendsMessages_GetActiveMessageSessions_ResponseFriendMessageSession"
    ] = betterproto.message_field(1)
    timestamp: int = betterproto.uint32_field(2)


@dataclass
class CFriendsMessages_GetActiveMessageSessions_ResponseFriendMessageSession(betterproto.Message):
    accountid_friend: int = betterproto.uint32_field(1)
    last_message: int = betterproto.uint32_field(2)
    last_view: int = betterproto.uint32_field(3)
    unread_message_count: int = betterproto.uint32_field(4)


@dataclass
class CFriendMessages_SendMessage_Request(betterproto.Message):
    steamid: float = betterproto.fixed64_field(1)
    chat_entry_type: int = betterproto.int32_field(2)
    message: str = betterproto.string_field(3)
    contains_bbcode: bool = betterproto.bool_field(4)
    echo_to_sender: bool = betterproto.bool_field(5)
    low_priority: bool = betterproto.bool_field(6)
    client_message_id: str = betterproto.string_field(8)


@dataclass
class CFriendMessages_SendMessage_Response(betterproto.Message):
    modified_message: str = betterproto.string_field(1)
    server_timestamp: int = betterproto.uint32_field(2)
    ordinal: int = betterproto.uint32_field(3)
    message_without_bb_code: str = betterproto.string_field(4)


@dataclass
class CFriendMessages_AckMessage_Notification(betterproto.Message):
    steamid_partner: float = betterproto.fixed64_field(1)
    timestamp: int = betterproto.uint32_field(2)


@dataclass
class CFriendMessages_IncomingMessage_Notification(betterproto.Message):
    steamid_friend: float = betterproto.fixed64_field(1)
    chat_entry_type: int = betterproto.int32_field(2)
    from_limited_account: bool = betterproto.bool_field(3)
    message: str = betterproto.string_field(4)
    rtime32_server_timestamp: float = betterproto.fixed32_field(5)
    ordinal: int = betterproto.uint32_field(6)
    local_echo: bool = betterproto.bool_field(7)
    message_no_bbcode: str = betterproto.string_field(8)
    low_priority: bool = betterproto.bool_field(9)
